//Libraries espnow and wifi
#include <esp_now.h>
#include <WiFi.h>

// Pin used for reading
// and the value will be sent
#define PIN 2

// Channel used for connection
#define CHANNEL 1

// If MASTER is set
// the compiler will compile the Master.ino
// If you want to compile Slave.ino remove or
// comment the line below
#define MASTER

// Structure with information
// about the next peer
esp_now_peer_info_t peer;

// Function to initialize the station mode
void modeStation() {
  // We put the ESP in station mode
  WiFi.mode(WIFI_STA);
  // We show on Serial Monitor the Mac Address
  // of this ESP when in station mode
  Serial.print("Mac Address in Station: ");
  Serial.println(WiFi.macAddress());
}

// ESPNow startup function
void InitESPNow() {
  // If the initialization was successful
  if (esp_now_init() == ESP_OK) {
    Serial.println("ESPNow Init Success");
  }
  // If initialization failed
  else {
    Serial.println("ESPNow Init Failed");
    ESP.restart();
  }
}

// Function that adds a new peer
// through your MAC address
void addPeer(uint8_t *peerMacAddress) {
  // We inform the channel
  peer.channel = CHANNEL;
  // 0 not to use encryption or 1 to use
  peer.encrypt = 0;
  // Copy array address to structure
  memcpy(peer.peer_addr, peerMacAddress, 6);
  // Add slave
  esp_now_add_peer(&peer);
}

// Function that will send the value to
// the peer that has the specified mac address
void send(const uint8_t *value, uint8_t *peerMacAddress) {
  esp_err_t result = esp_now_send(peerMacAddress, value, sizeof(value));
  Serial.print("Send Status: ");
  // If the submission was successful
  if (result == ESP_OK) {
    Serial.println("Success");
  }
  // If there was an error sending
  else {
    Serial.println("Error");
  }
}
