// will only compile if MASTER is set
#ifdef MASTER

// Mac Address of the peer to which we will send the data
uint8_t peerMacAddress[] = {0x24, 0x0A, 0xC4, 0x0E, 0x3F, 0xD0};

void setup() {
  Serial.begin(115200);

  // Call the function that initializes the station mode
  modeStation();

  // Call function that initializes ESPNow
  InitESPNow();

  // Add the peer
  addPeer(peerMacAddress);

  // Registers the callback that will inform us
  // about the status of the submission.
  // The function that will be executed is onDataSent
  // and is stated below
  esp_now_register_send_cb(OnDataSent);

  // We put the pin in read mode
  pinMode(PIN, INPUT);

  // Read the pin value and send
  readAndSend();
}

// Function responsible for
// pin reading and sending
// of the value for the peer
void readAndSend() {
  // Read the value of the pin
  uint8_t value = digitalRead(PIN);
  // Send the value to the peer
  send(&value, peerMacAddress);
}

// Function that serves as a callback to warn us
// about the sending situation we made
void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Success" : "Fail");

// When we receive the result of the last sending
// we can read and send again
  readAndSend();
}

// We do not need to do anything in the loop
// because whenever we receive the feedback
// of sending through the OnDataSent function
// we send the data again,
// making the data always
// being sent in sequence
void loop() {
}
#endif
