// will only compile if MASTER is not set
#ifndef MASTER

// Mac Address of the peer to which we will send the data
uint8_t peerMacAddress[6] = {0x24, 0x0A, 0xC4, 0x0E, 0x46, 0xCC};

void setup() {
  Serial.begin(115200);

  // Call the function that initializes the station mode
  modeStation();

  // Call function that initializes ESPNow
  InitESPNow();

  // Add the peer
  addPeer(peerMacAddress);

  // Registers the callback that will inform us
  // that we receive data.
  // The function to be executed
  // is onDataRecv and is declared below
  esp_now_register_recv_cb(onDataRecv);

  // Registers the callback that will inform us
  // about the status of the submission.
  // The function to be executed
  // is onDataSent and is declared below
  esp_now_register_send_cb(onDataSent);

  // We put the pin as output
  pinMode(PIN, OUTPUT);
}

// Function that serves as a callback to warn us
// we receive data
void onDataRecv(const uint8_t *mac_addr, const uint8_t *value, int len) {
  // Place the received value at the output of the pin
  digitalWrite(PIN, *value);
  // Send the read value to the next esp
  // If this is the last, comment out this line before compiling
  send(value, peerMacAddress);
}

// Function that serves as a callback to warn us
// about the sending situation we made
void onDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Success" : "Fail");
}

// We do not need to do anything in the loop
// we send the data as soon as
// we get from the other esp by the callback
void loop() {
}
#endif
